from abc import ABC, abstractmethod
from .shipyard_logger import ShipyardLogger


class Spreadsheets(ABC):

    def __init__(self, **kwargs) -> None:
        self.logger = ShipyardLogger().logger
        super().__init__()

    @abstractmethod
    def connect(self):
        pass



import logging


class ShipyardLogger():

    def __init__(self) -> None:
        self.LOGDATA = False

        self.logger = logging.getLogger("Shipyard")
        self.logger.setLevel(logging.DEBUG)
        # Add handler for stderr
        console = logging.StreamHandler()
        console.setLevel(logging.DEBUG)
        # add specific format
        formatter = logging.Formatter(
            '%(asctime)s - %(name)s - %(levelname)s - %(message)s')
        console.setFormatter(formatter)
        self.logger.addHandler(console)



from abc import ABC, abstractmethod
from .shipyard_logger import ShipyardLogger


class Messaging(ABC):
    def __init__(self, **kwargs) -> None:
        self.logger = ShipyardLogger().logger

    @abstractmethod
    def connect():
        pass




from abc import ABC, abstractmethod
from .shipyard_logger import ShipyardLogger


class CloudStorage(ABC):
    EXIT_CODE_INVALID_CREDENTIALS = 202

    def __init__(self, **kwargs) -> None:
        self.logger = ShipyardLogger().logger

    @abstractmethod
    def download_files(self):
        pass

    @abstractmethod
    def move_or_rename_files(self):
        pass

    @abstractmethod
    def remove_files(self):
        pass

    @abstractmethod
    def upload_files(self):
        pass

    @abstractmethod
    def connect(self):
        pass



from .cloudstorage import CloudStorage
from .database import Database, GoogleDatabase
from .datavisualization import DataVisualization
from .etl import Etl    
from .messaging import Messaging
from .notebooks import Notebooks
from .shipyard_logger import ShipyardLogger
from .spreadsheets import Spreadsheets
